==> pointpos_api-0.0.16.tar.gz: test/role_permission_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for RolePermissionApi
void main() {
  var instance = new RolePermissionApi();

  group('tests for RolePermissionApi', () {
    // Create Rolepermission
    //
    // Create Rolepermission
    //
    //Future<RolePermission> createRolepermission(String authorization, String xAPIKey, RolePermission body, { String xPin }) async 
    test('test createRolepermission', () async {
      // TODO
    });

    // Delete Rolepermission By ID
    //
    // Delete Rolepermission By ID
    //
    //Future deleteRolepermissionByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteRolepermissionByID', () async {
      // TODO
    });

    // Get Rolepermission List
    //
    // Get Rolepermission  List
    //
    //Future<List<RolePermission>> findRolepermission(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findRolepermission', () async {
      // TODO
    });

    // Get Rolepermission By ID
    //
    // Get Rolepermission By ID
    //
    //Future<RolePermission> getRolepermissionByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getRolepermissionByID', () async {
      // TODO
    });

    // Update Rolepermission By ID
    //
    // Update [object Object] By ID
    //
    //Future<RolePermission> updateRolepermissionByID(String authorization, String xAPIKey, String id, RolePermission body, { String xPin }) async 
    test('test updateRolepermissionByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/role_permission_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for RolePermissionApi
void main() {
  var instance = new RolePermissionApi();

  group('tests for RolePermissionApi', () {
    // Create Rolepermission
    //
    // Create Rolepermission
    //
    //Future<RolePermission> createRolepermission(String authorization, String xAPIKey, RolePermission body, { String xPin }) async 
    test('test createRolepermission', () async {
      // TODO
    });

    // Delete Rolepermission By ID
    //
    // Delete Rolepermission By ID
    //
    //Future deleteRolepermissionByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteRolepermissionByID', () async {
      // TODO
    });

    // Get Rolepermission List
    //
    // Get Rolepermission  List
    //
    //Future<List<RolePermission>> findRolepermission(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findRolepermission', () async {
      // TODO
    });

    // Get Rolepermission By ID
    //
    // Get Rolepermission By ID
    //
    //Future<RolePermission> getRolepermissionByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getRolepermissionByID', () async {
      // TODO
    });

    // Update Rolepermission By ID
    //
    // Update [object Object] By ID
    //
    //Future<RolePermission> updateRolepermissionByID(String authorization, String xAPIKey, String id, RolePermission body, { String xPin }) async 
    test('test updateRolepermissionByID', () async {
      // TODO
    });

  });
}
